summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmpatternedit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmpatternedit.h')
-rw-r--r--kpovmodeler/pmpatternedit.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kpovmodeler/pmpatternedit.h b/kpovmodeler/pmpatternedit.h
index fea9f140..18c250db 100644
--- a/kpovmodeler/pmpatternedit.h
+++ b/kpovmodeler/pmpatternedit.h
@@ -49,9 +49,9 @@ class PMPatternEdit : public PMDialogEditBase
typedef PMDialogEditBase Base;
public:
/**
* Creates a PMPatternEdit with tqparent and name
*/
- PMPatternEdit( TQWidget* tqparent, const char* name = 0 );
+ PMPatternEdit( TQWidget* parent, const char* name = 0 );
/** */
virtual void displayObject( PMObject* o );
@@ -49,9 +49,9 @@ class PMPatternEdit : public PMDialogEditBase
public:
/**
- * Creates a PMPatternEdit with tqparent and name
+ * Creates a PMPatternEdit with parent and name
*/